@@ -2,15 +2,15 @@ package SOAP::WSDL::Deserializer::SOM;
 use strict;
 use warnings;
 
-our $VERSION = '2.00_15';
+our $VERSION = '2.00_24';
 our @ISA;
 
-eval { 
+eval {
     require SOAP::Lite;
-    push @ISA, 'SOAP::Deserializer'; 
+    push @ISA, 'SOAP::Deserializer';
 }
-or die "Cannot load SOAP::Lite. 
-Cannot deserialize to SOM object without SOAP::Lite. 
+or die "Cannot load SOAP::Lite.
+Cannot deserialize to SOM object without SOAP::Lite.
 Please install SOAP::Lite.";
 
 sub generate_fault {
@@ -48,29 +48,27 @@ This package is here for two reasons:
 
 =item * Compatibility
 
-You don't have to change the rest of your SOAP::Lite based app when switching 
-to SOAP::WSDL, but can just use SOAP::WSDL::Deserializer::SOM to get back the 
+You don't have to change the rest of your SOAP::Lite based app when switching
+to SOAP::WSDL, but can just use SOAP::WSDL::Deserializer::SOM to get back the
 same objects as you were used to.
 
 =item * Completeness
 
-SOAP::Lite covers much more of the SOAP specification than SOAP::WSDL. 
+SOAP::Lite covers much more of the SOAP specification than SOAP::WSDL.
 
-SOAP::WSDL::Deserializer::SOM can be used for content which cannot be 
-deserialized by L<SOAP::WSDL::Deserializer::SOAP11|SOAP::WSDL::Deserializer::SOAP11>. 
-This may be XML including mixed content, attachements and other XML data not 
-(yet) handled by L<SOAP::WSDL::Deserializer::SOAP11|SOAP::WSDL::Deserializer::SOAP11>. 
+SOAP::WSDL::Deserializer::SOM can be used for content which cannot be
+deserialized by L<SOAP::WSDL::Deserializer::SOAP11|SOAP::WSDL::Deserializer::SOAP11>.
+This may be XML including mixed content, attachements and other XML data not
+(yet) handled by L<SOAP::WSDL::Deserializer::SOAP11|SOAP::WSDL::Deserializer::SOAP11>.
 
 =back
 
-SOAP::WSDL::Deserializer::SOM is a subclass of L<SOAP::Deserializer|SOAP::Deserializer> 
-from the L<SOAP::Lite|SOAP::Lite> package. 
-
-You may 
+SOAP::WSDL::Deserializer::SOM is a subclass of L<SOAP::Deserializer|SOAP::Deserializer>
+from the L<SOAP::Lite|SOAP::Lite> package.
 
 =head1 USAGE
 
-SOAP::WSDL::Deserializer will not auroregister itself - to use it for a particular 
+SOAP::WSDL::Deserializer will not auroregister itself - to use it for a particular
 SOAP version just use the following lines:
 
  my $soap_version = '1.1'; # or '1.2', further versions may appear.
@@ -87,7 +85,7 @@ SOAP version just use the following lines:
 
 =item * No on_fault handler
 
-You cannot specify what to do when an error occurs - SOAP::WSDL will die 
+You cannot specify what to do when an error occurs - SOAP::WSDL will die
 with a SOAP::Fault object on transport errors.
 
 =back
@@ -98,17 +96,17 @@ with a SOAP::Fault object on transport errors.
 
 =item * generate_fault
 
-SOAP::WSDL::Deserializer::SOM will die with a SOAP::Fault object on calls 
+SOAP::WSDL::Deserializer::SOM will die with a SOAP::Fault object on calls
 to generate_fault.
 
 =back
 
-=head1 LICENSE
+=head1 LICENSE AND COPYRIGHT
 
 Copyright 2004-2007 Martin Kutter.
 
-This file is part of SOAP-WSDL. You may distribute/modify it under 
-the same terms as perl itself
+This file is part of SOAP-WSDL. You may distribute/modify it under
+the same terms as perl itself.
 
 =head1 AUTHOR
 
@@ -116,9 +114,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 176 $
+ $Rev: 391 $
  $LastChangedBy: kutterma $
- $Id: Serializer.pm 176 2007-08-31 15:28:29Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Factory/Serializer.pm $
- 
+ $Id: SOM.pm 391 2007-11-17 21:56:13Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Deserializer/SOM.pm $
+
 =cut
