@@ -6,7 +6,7 @@ use Scalar::Util qw(blessed);
 use SOAP::WSDL::Factory::Deserializer;
 use SOAP::WSDL::Factory::Serializer;
 
-use version; our $VERSION = qv('2.00.10');
+our $VERSION = q{2.00_25};
 
 my %dispatch_to_of      :ATTR(:name<dispatch_to> :default<()>);
 my %action_map_ref_of   :ATTR(:name<action_map_ref> :default<{}>);
@@ -28,7 +28,7 @@ sub handle {
         soap_version => '1.1'
     });
 
-# TODO: factor out dispatcher logic into dispatcher factory + dispatcher
+# TODO: factor out dispatcher logic into dispatcher factory + dispatcher 
 # classes
 #    $dispatcher_of{ $ident } ||= SOAP::WSDL::Factory::Dispatcher->get_dispatcher({});
 
@@ -42,7 +42,7 @@ sub handle {
     };
     if ($@) {
         die $deserializer_of{ $ident }->generate_fault({
-                code => 'SOAP-ENV:Server',
+                code => 'soap:Server',
                 role => 'urn:localhost',
                 message => "Error deserializing message: $@. \n"
             });
@@ -65,7 +65,7 @@ sub handle {
 
     if (!$dispatch_to_of{ $ident }) {
         die $deserializer_of{ $ident }->generate_fault({
-                code => 'SOAP-ENV:Server',
+                code => 'soap:Server',
                 role => 'urn:localhost',
                 message => "No handler registered",
             });
@@ -73,7 +73,7 @@ sub handle {
 
     if (! defined $request->header('SOAPAction') ) {
         die $deserializer_of{ $ident }->generate_fault({
-                code => 'SOAP-ENV:Server',
+                code => 'soap:Server',
                 role => 'urn:localhost',
                 message => "Not found: No SOAPAction given",
             });
@@ -81,7 +81,7 @@ sub handle {
 
     if (! defined $method_name) {
         die $deserializer_of{ $ident }->generate_fault({
-                code => 'SOAP-ENV:Server',
+                code => 'soap:Server',
                 role => 'urn:localhost',
                 message => "Not found: No method found for the SOAPAction '$soap_action'",
             });
@@ -92,7 +92,7 @@ sub handle {
 
     if (!$method_ref) {
         die $deserializer_of{ $ident }->generate_fault({
-                code => 'SOAP-ENV:Server',
+                code => 'soap:Server',
                 role => 'urn:localhost',
                 message => "Not implemented: The handler does not implement the method $method_name",
             });
@@ -143,12 +143,12 @@ SOAP::WSDL::Server basically follows the architecture sketched below
   |   Handler                           |
    -------------------------------------
 
-All of the components (Transport class, deserializer, dispatcher and
+All of the components (Transport class, deserializer, dispatcher and 
 serializer) are implemented as plugins.
 
-The architecture is not implemented as planned yet, but the dispatcher is
+The architecture is not implemented as planned yet, but the dispatcher is 
 currently part of SOAP::WSDL::Server, which aggregates serializer and
-deserializer, and is subclassed by transport classes (of which
+deserializer, and is subclassed by transport classes (of which 
 SOAP::WSDL::Server::CGI is the only implemented one yet).
 
 The dispatcher is currently based on the SOAPAction header. This does not
@@ -160,80 +160,9 @@ of the deserialized messages).
 A hash-based dispatcher could be implemented by examining the top level
 hash keys.
 
-=head1 EXCEPTION HANDLING
-
-=head2 Builtin exceptions
-
-SOAP::WSDL::Server handles the following errors itself:
-
-In case of errors, a SOAP Fault containing an appropriate error message
-is returned.
-
-=over
-
-=item * XML parsing errors
-
-=item * Configuration errors
-
-=back
-
-=head2 Throwing exceptions
-
-The proper way to throw a exception is just to die -
-SOAP::WSDL::Server::CGI catches the exception and sends a SOAP Fault
-back to the client.
-
-If you want more control over the SOAP Fault sent to the client, you can
-die with a SOAP::WSDL::SOAP::Fault11 object - or just let the
-SOAP::Server's deserializer create one for you:
-
- my $soap = MyServer::SomeService->new();
-
- die $soap->get_deserializer()->generate_fault({
-    code => 'SOAP-ENV:Server',
-    role => 'urn:localhost',
-    message => "The error message to pas back",
-    detail => "Some details on the error",
- });
-
-You may use any other object as exception, provided it has a
-serialize() method which returns the object's XML representation.
-
-=head2 Subclassing
-
-To write a transport-specific SOAP Server, you should subclass
-SOAP::WSDL::Server.
-
-See the C<SOAP::WSDL::Server::*> modules for examples.
-
-A SOAP Server must call the following method to actually handle the request:
-
-=head3 handle
-
-Handles the SOAP request.
-
-Returns the response message as XML.
-
-Expects a C<HTTP::Request> object as only parameter.
-
-You may use any other object as parameter, as long as it implements the
-following methods:
-
-=over
-
-=item * header
-
-Called as header('SOAPAction'). Must return the corresponding HTTP header.
-
-=item * content
-
-Returns the request message
-
-=back
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2004-2008 Martin Kutter.
+Copyright 2004-2007 Martin Kutter.
 
 This file is part of SOAP-WSDL. You may distribute/modify it under the same
 terms as perl itself
